# LiteRAG

[![CCDS-Project template](https://img.shields.io/badge/CCDS-Project%20template-328F97?logo=cookiecutter)](https://cookiecutter-data-science.drivendata.org/)

Call all RAG APIs using thee same format. Use Azure Search, OpenAI, Pinecone, etc.
